### Detailed Activity Analysis of Chat Participants _( by minute )_
In previous section, I tried to find out how users are spending their time in Chat(s), which we're analyzing, by splitting the whole day into **8** equal parts.

Time for some detailed investigation ... :wink:

Here I'm going to split whole day into 4 equal parts and draw 4 subplots, where I'll try to depict how a user spent each minute of his/ her day _( 1440 minutes in a day )_ over this period of time _( for which we've Chat record )_, in this Chat.

It'll be helpful in understanding, when this user is generally more or less active _( i.e. activity patterns / sleep patterns )_, depending upon what we're observing for this period of time.

No doubt you've already understood, if you had a very long Private Chat with a person or a high traffic group, consider analyzing that Chat file, you'll be happy to learn much more about those participating peoples.

So I applied `util.plotActivityOfUserByMinute()` on a collection of messages from each Participants of Chat _( both Private & Group )_, and result was really interesting.

Check them out.

#### For Private Chat :
1.

![detailedActivityOfParticipantOne](../plots/detailedActivityOf1InPrivateChatByMinute.svg)
2.

![detailedActivityOfParticipantTwo](../plots/detailedActivityOf2InPrivateChatByMinute.svg)

#### For Group Chat :
1.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf1InGroupChatByMinute.svg)

2.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf2InGroupChatByMinute.svg)

3.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf3InGroupChatByMinute.svg)

4.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf4InGroupChatByMinute.svg)

5.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf5InGroupChatByMinute.svg)

6.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf6InGroupChatByMinute.svg)

7.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf7InGroupChatByMinute.svg)


8.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf8InGroupChatByMinute.svg)


9.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf9InGroupChatByMinute.svg)


10.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf10InGroupChatByMinute.svg)


11.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf11InGroupChatByMinute.svg)

12.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf12InGroupChatByMinute.svg)

13.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf13InGroupChatByMinute.svg)

14.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf14InGroupChatByMinute.svg)

15.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf15InGroupChatByMinute.svg)

16.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf16InGroupChatByMinute.svg)

17.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf17InGroupChatByMinute.svg)


18.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf18InGroupChatByMinute.svg)


19.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf19InGroupChatByMinute.svg)

20.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf20InGroupChatByMinute.svg)

21.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf21InGroupChatByMinute.svg)

22.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf22InGroupChatByMinute.svg)

23.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf23InGroupChatByMinute.svg)

24.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf24InGroupChatByMinute.svg)

25.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf25InGroupChatByMinute.svg)

26.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf26InGroupChatByMinute.svg)

27.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf27InGroupChatByMinute.svg)


28.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf28InGroupChatByMinute.svg)


29.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf29InGroupChatByMinute.svg)


30.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf30InGroupChatByMinute.svg)

31.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf31InGroupChatByMinute.svg)

32.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf32InGroupChatByMinute.svg)

33.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf33InGroupChatByMinute.svg)

34.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf34InGroupChatByMinute.svg)

35.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf35InGroupChatByMinute.svg)

36.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf36InGroupChatByMinute.svg)

37.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf37InGroupChatByMinute.svg)


38.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf38InGroupChatByMinute.svg)


39.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf39InGroupChatByMinute.svg)

40.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf40InGroupChatByMinute.svg)


41.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf41InGroupChatByMinute.svg)

42.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf42InGroupChatByMinute.svg)

43.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf43InGroupChatByMinute.svg)

44.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf44InGroupChatByMinute.svg)

45.

![detailedActivityOfParticipantInGroupChat](../plots/detailedActivityOf45InGroupChatByMinute.svg)

